GBUiKitLocalizations class

Constructors

GBUiKitLocalizations()

Properties

alreadyHaveAnAccount → String
Already have an account?
no setter
changeTheEmailAddress → String
Change the email address
no setter
code → String
Code
no setter
confirm → String
Confirm
no setter
confirmAccount → String
Confirm Account
no setter
confirmPassword → String
Confirm Password
no setter
confirmYourPassword → String
Confirm your password
no setter
continuee → String
Continue
no setter
didntReceiveCode → String
Didn’t receive code?
no setter
dontHaveAnAccount → String
Don’t have an account?
no setter
email → String
Email
no setter
enterYourEmail → String
Enter your email
no setter
enterYourFirstName → String
Enter your first name
no setter
enterYourLastName → String
Enter your last name
no setter
enterYourName → String
Enter your name
no setter
enterYourPassword → String
Enter your password
no setter
enterYourUsername → String
Enter your username
no setter
error → String
Error
no setter
fillTheFormAndSignUp → String
Fill the form and sign up.
no setter
firstName → String
First Name
no setter
forgotPassword → String
Forgot password
no setter
forgotYourPassword → String
Forgot your password?
no setter
hashCode → int
The hash code for this object.
no setterinherited
hello → String
Hello
no setter
insertTheVerificationCodeYouReceiveInYourMail → String
Insert the verification code you receive in your mail.
no setter
lastName → String
Last Name
no setter
loginToYourAccount → String
Login to your account.
no setter
newPassword → String
New Password
no setter
password → String
Password
no setter
paste → String
Paste
no setter
resetPassword → String
Reset Password
no setter
resetPasswordDescription → String
Enter the email associated with your account and we’ll send and email with instructions to reset your password
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
save → String
Save
no setter
send → String
Send
no setter
sendAgain → String
Send Again
no setter
signIn → String
Sign In
no setter
signUp → String
Sign Up
no setter
signup → String
Signup
no setter
state → String
State
no setter
tryAgain → String
Try Again
no setter
typeToFilter → String
Type to filter ...
no setter
unknownFailure → String
Unknown Failure
no setter
username → String
Username
no setter
welcome → String
Welcome
no setter
youCannotProvideBothLabelAndLabelwidgetAtTheSame → String
You cannot provide both 'label' and 'labelWidget' at the same time.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

current → GBUiKitLocalizations
no setter

Constants

delegate → const AppLocalizationDelegate