AppBar class

Inheritance
Implemented types
Available extensions

Constructors

AppBar({Key? key, String? title, Color? textColor, List<Widget>? actions, bool automaticallyImplyLeading = true, Widget? leading, Color? backgroundColor, double height = 44, Widget? flexibleSpace, SystemUiOverlayStyle? systemOverlayStyle})
const
AppBar.expanded({String? title, Color? textColor, List<Widget>? actions, bool automaticallyImplyLeading = true, Widget? leading, Color? backgroundColor, SystemUiOverlayStyle? systemOverlayStyle})
factory

Properties

actions → List<Widget>?
final
automaticallyImplyLeading → bool
final
backgroundColor → Color?
final
flexibleSpace → Widget?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading → Widget?
final
preferredSize → Size
The size this widget would prefer if it were otherwise unconstrained.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
systemOverlayStyle → SystemUiOverlayStyle?
Specifies the style to use for the system overlays (e.g. the status bar on Android or iOS, the system navigation bar on Android).
final
textColor → Color?
final
title → String?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _AppBarState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
withGBInputWrapper({String? label, Widget? labelWidget, bool appendColonToLabel = true, TextStyle? labelStyle, String? errorText, bool hasError = false, List<InputFeedbackText>? feedback, WrapWidgetBuilder? innerBoxWrapper, BoxConstraints? constraints}) → Widget

Available on Widget, provided by the GBInputWrapperExtension extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited