GBButtonChild class

Consolidated child widget for GB UI Kit buttons (ContainedButton, OutlinedButton).

Handles debounced loading state with ButtonProgressIndicator and optional full-surface gradient rendering via Ink.

Inheritance
Available extensions

Constructors

GBButtonChild({Key? key, required bool busy, Color? busyColor, Duration? loadingDebounce, required Widget child, GBButtonGradient? gradient, BorderRadius? borderRadius, EdgeInsetsGeometry? padding, double? minWidth, double? height})
const

Properties

borderRadius BorderRadius?
final
busy bool
final
busyColor Color?
final
child Widget
final
gradient GBButtonGradient?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingDebounce Duration?
final
minWidth double?
final
padding EdgeInsetsGeometry?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
withGBInputWrapper({String? label, Widget? labelWidget, bool appendColonToLabel = true, TextStyle? labelStyle, String? errorText, bool hasError = false, List<InputFeedbackText>? feedback, WrapWidgetBuilder? innerBoxWrapper, BoxConstraints? constraints}) Widget

Available on Widget, provided by the GBInputWrapperExtension extension

Operators

operator ==(Object other) bool
The equality operator.
inherited