OutlinedButton class

Inheritance
Available extensions

Constructors

OutlinedButton({Key? key, required VoidCallback? onPressed, VoidCallback? onLongPress, ValueChanged<bool>? onHover, ValueChanged<bool>? onFocusChange, ButtonStyle? style, FocusNode? focusNode, bool autofocus = false, Clip clipBehavior = Clip.none, WidgetStatesController? statesController, bool busy = false, Color? busyColor, Duration? loadingDebounce, bool disabled = false, Color? color, BorderRadius? borderRadius, EdgeInsetsGeometry? padding, double? minWidth, double? height, double? borderWidth, bool? guessTextColor, Widget? child})
OutlinedButton.large({Key? key, Widget? child, String? text, Color? color, bool uppercase = true, bool busy = false, required VoidCallback? onPressed, Color? busyColor, Duration? loadingDebounce, BorderRadius? borderRadius, bool? guessTextColor, EdgeInsets? padding, bool disabled = false, double? borderWidth, ButtonStyle? style})
factory
OutlinedButton.small({Key? key, Widget? child, String? text, Color? color, bool uppercase = true, bool busy = false, Color? busyColor, required VoidCallback? onPressed, Duration? loadingDebounce, BorderRadius? borderRadius, bool? guessTextColor, EdgeInsets? padding, bool disabled = false, double? borderWidth, double minWidth = 164, ButtonStyle? style})
factory
OutlinedButton.text(String text, {Key? key, Color? color, double? minWidth, double? height, bool uppercase = true, bool busy = false, Color? busyColor, required VoidCallback? onPressed, Duration? loadingDebounce, BorderRadius? borderRadius, bool? guessTextColor, EdgeInsets? padding, bool disabled = false, double? borderWidth, ButtonStyle? style})
factory

Properties

autofocus → bool
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
finalinherited
busy → bool
final
busyColor → Color?
final
child → Widget?
Typically the button's label.
finalinherited
clipBehavior → Clip?
The content will be clipped (or not) according to this option.
finalinherited
enabled → bool
Whether the button is enabled or disabled.
no setterinherited
focusNode → FocusNode?
An optional focus node to use as the focus node for this widget.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
iconAlignment → IconAlignment?
Determines the alignment of the icon within the widgets such as:
finalinherited
isSemanticButton → bool?
Determine whether this subtree represents a button.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingDebounce → Duration?
final
onFocusChange → ValueChanged<bool>?
Handler called when the focus changes.
finalinherited
onHover → ValueChanged<bool>?
Called when a pointer enters or exits the button response area.
finalinherited
onLongPress → VoidCallback?
Called when the button is long-pressed.
finalinherited
onPressed → VoidCallback?
Called when the button is tapped or otherwise activated.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statesController → MaterialStatesController?
Represents the interactive "state" of this widget in terms of a set of WidgetStates, like WidgetState.pressed and WidgetState.focused.
finalinherited
style → ButtonStyle?
Customizes this button's appearance.
finalinherited
tooltip → String?
Text that describes the action that will occur when the button is pressed or hovered over.
finalinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<ButtonStyleButton>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
defaultStyleOf(BuildContext context) → ButtonStyle
Defines the button's default appearance.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
themeStyleOf(BuildContext context) → ButtonStyle?
Returns the ButtonStyle that belongs to the button's component theme.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
withGBInputWrapper({String? label, Widget? labelWidget, bool appendColonToLabel = true, TextStyle? labelStyle, String? errorText, bool hasError = false, List<InputFeedbackText>? feedback, WrapWidgetBuilder? innerBoxWrapper, BoxConstraints? constraints}) → Widget

Available on Widget, provided by the GBInputWrapperExtension extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited