CodeField class

Inheritance
Available extensions

Constructors

CodeField({Key? key, int length = 6, TextStyle? labelStyle, TextStyle? textStyle, bool enabled = true, bool? filled, String? label, Widget? labelWidget, bool appendColonToLabel = true, String? errorText, ValueChanged<String>? onChanged, BorderRadius? borderRadius, List<InputFeedbackText>? feedback, TextInputType? keyboardType, dynamic onSubmitted(String value)?, TextInputAction textInputAction = material.TextInputAction.done, List<TextInputFormatter>? inputFormatters, bool forceUppercase = false, WrapWidgetBuilder? innerBoxWrapper, String? value, String? hintText, bool forceErrorStyle = false, AlignmentGeometry fieldAlignment = Alignment.center, double inputBoxSize = 45, TextCapitalization textCapitalization = material.TextCapitalization.none})
const

Properties

appendColonToLabel → bool
final
borderRadius → BorderRadius?
final
enabled → bool
final
errorText → String?
final
feedback → List<InputFeedbackText>?
final
fieldAlignment → AlignmentGeometry
final
filled → bool?
final
forceErrorStyle → bool
Provides a way to force error style (normally red colored)
final
forceUppercase → bool
If true , this will set each char to uppercase, this is accomplished by adding a input-formatter
final
hashCode → int
The hash code for this object.
no setterinherited
hintText → String?
Pass a text to be used as hintText
final
innerBoxWrapper → WrapWidgetBuilder?
Defines a custom builder widget that will wrap the TexField inner box This is useful to for example wrap your widget inside a Material elevation, etc
final
inputBoxSize → double
Customize the size of the input fields boxes
final
inputFormatters → List<TextInputFormatter>?
Optional input validation and formatting overrides.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType?
final
label → String?
final
labelStyle → TextStyle?
Define a custom style to be used in the label of the field
final
labelWidget → Widget?
final
length → int
final
onChanged → ValueChanged<String>?
final
onSubmitted → dynamic Function(String value)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textCapitalization → TextCapitalization
final
textInputAction → TextInputAction
final
textStyle → TextStyle?
final
value → String?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _CodeFieldState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
withGBInputWrapper({String? label, Widget? labelWidget, bool appendColonToLabel = true, TextStyle? labelStyle, String? errorText, bool hasError = false, List<InputFeedbackText>? feedback, WrapWidgetBuilder? innerBoxWrapper, BoxConstraints? constraints}) → Widget

Available on Widget, provided by the GBInputWrapperExtension extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited