presentation/inputs/inputs library

Classes

AddressStateSelectField
CodeField
GBInputWrapper
A layout wrapper that adds an external label, animated error message, and feedback checklist around any input widget (e.g. standard TextField, TextFormField, CupertinoTextField, or custom inputs).
MultiSelectField<T>
PasswordField
PasswordFieldState
SelectField<T>
SelectFieldBase<T>
SelectFieldOption<T>
Switcher
TextField

Extensions

GBInputWrapperExtension on Widget
Convenience extension on Widget to easily wrap any input with GBInputWrapper.

Properties

theStates ↔ List
getter/setter pair

Typedefs

SelectTrailingBuilder = Widget Function(BuildContext context, int index, bool isSelected)