presentation/inputs/text_field/input_wrapper library

Classes

GBInputWrapper
A layout wrapper that adds an external label, animated error message, and feedback checklist around any input widget (e.g. standard TextField, TextFormField, CupertinoTextField, or custom inputs).

Extensions

GBInputWrapperExtension on Widget
Convenience extension on Widget to easily wrap any input with GBInputWrapper.