presentation/presentation library

Classes

AccountCodeConfirmationTemplate
AddressStateSelectField
AnimatableStateListView<T>
A useful widget to render animated list views, it handles insert and remove animations based on input data changes
AnimatedDisplayable
AnimatedFadeHeightSwitcher
AnimatedPlaceholder
AppBar
AppLocalizationDelegate
BottomNavBar
BottomNavItem
ChildSizeListener
A utility widget that monitors the size of its child and notifies a callback when the size changes.
CodeField
ComposedActionText
ContainedButton
ContainedButtonTheme
Overrides the default ButtonStyle of its TextButton descendants.
ContainedButtonThemeData
A ButtonStyle that overrides the default appearance of TextButtons when it's used with ContainedButtonTheme or with the overall Theme's ThemeData.textButtonTheme.
DefaultBottomItem
DefaultLoadingStyle
ErrorTemplate
GBButtonChild
Consolidated child widget for GB UI Kit buttons (ContainedButton, OutlinedButton).
GBButtonGradient
GBIcons
GBInputDecorationTheme
GBInputWrapper
A layout wrapper that adds an external label, animated error message, and feedback checklist around any input widget (e.g. standard TextField, TextFormField, CupertinoTextField, or custom inputs).
GBScaffold
GBText
GBTheme
GBThemeData
GBUiKitLocalizations
GenericDataHandlerWidget
A widget that helps you handling loading, errors and data through the UI with animations
GenericErrorRetry
HandlePasteBuilder
HaveAnAccountLegend
InputFeedbackContainer
InputFeedbackText
LinkButton
A button that looks like a hyperlink, extending Flutter's material.TextButton.
LoadingDebouncedBuilder
This widget allows you to debounce a loading state so you can implement transition if state changes too fast sometimes it doesn't have enough time to display a loading indicator this widget tries to solve that issue when changing to loading state transition will begin inmediatly, when loading state changes to false it will wait for the debounce time before staring the transition
LoadingDebouncedSwitcher
This widget allows you to switch between a loading state and a normal, when APIs act too fast sometimes it doesn't have enough time to display a loading indicator this widget tries to solve that issue when changing to loading state transition will begin inmediatly, when loading state changes to false it will wait for the debounce time before staring the transition
LoadingTemplate
LoginTemplate
MultiSelectField<T>
MusicVisualizer
NewPasswordSetFields
NewPasswordSetFieldsState
NewPasswordSetFieldsStyle
OutlinedButton
OverlayCanvas
PasswordField
PasswordFieldState
PickedTime
RenderSliverSizeTransition
ResetPasswordCodeInputTemplate
ResetPasswordRequestTemplate
ResetPasswordSetTemplate
ScreenLoadingIndicator
A widget to be used to render a loading screen this will be useful to render a transition when screen navigation is occurring and a guard is processing async logic
SelectableRadio<T>
SelectField<T>
SelectFieldBase<T>
SelectFieldOption<T>
SignUpTemplate
SliverAppBar
SliverFooter
SliverFooterRenderObject
SliverSizeTransition
Step
Stepper
Switcher
TextField
TimePicker
TimerCountDownBuilder
A widget that builds itself based on a countdown timer.
TimerCountDownState
Represents the current state of a TimerCountDownBuilder.
UnavailableTime
ViewportOverflowListener
A utility widget that monitors its child's position and size to detect viewport overflow.

Extensions

GBInputWrapperExtension on Widget
Convenience extension on Widget to easily wrap any input with GBInputWrapper.
GBThemeContextExtension on BuildContext
Extension on BuildContext for shorthand access to ThemeData.
GBThemeDataExtension on ThemeData
Extension on ThemeData providing GB UI Kit theme builder and token accessors.
GBThemeExtension on Theme

Properties

theStates ↔ List
getter/setter pair

Functions

createGBChipTheme({required Color textBlack, required Color textBase, ChipThemeData? customTheme}) → ChipThemeData
Creates default ChipThemeData for GB UI Kit chips.
createGBElevatedButtonTheme({required Color accentColor, required Color backgroundDisabled, required Color textWhite, BorderRadiusGeometry? buttonsRadius, ElevatedButtonThemeData? customTheme}) → ElevatedButtonThemeData
Creates default ElevatedButtonThemeData for GB UI Kit buttons.
createGBInputDecorationTheme({required Color accentColor, required Color accentError, required Color accentErrorLight, required Color backgroundContrast, required Color backgroundDisabled, required Color backgroundFocus, required Color textBase, BorderRadius? textFieldRadius, double? textFieldBorderWidth, InputDecorationThemeData? customTheme}) → InputDecorationThemeData
Creates default InputDecorationThemeData for GB UI Kit fields.
createGBOutlinedButtonTheme({required Color secondary, required Color textBlack, required Color textDisabled, required Color backgroundDisabled, BorderRadiusGeometry? borderRadius, OutlinedButtonThemeData? customTheme}) → OutlinedButtonThemeData
Creates default OutlinedButtonThemeData for GB UI Kit buttons.
createGBSwitchTheme({required Color accentColor, required Color backgroundDisabled, SwitchThemeData? customTheme}) → SwitchThemeData
Creates default SwitchThemeData for GB UI Kit switches.
createGBTextTheme([TextTheme? customTextTheme]) → TextTheme
Creates default TextTheme for GB UI Kit typography.
createGBTheme({Color accentColor = DefaultColors.accent_accent_blue, Color accentError = DefaultColors.accent_error_red, Color accentErrorLight = DefaultColors.accent_error_red_light, Color backgroundBase = DefaultColors.background_base, Color backgroundContrast = DefaultColors.background_contrast, Color backgroundDisabled = DefaultColors.background_disabled, Color backgroundFocus = DefaultColors.background_focus, Color primaryColor = DefaultColors.primaryPrimaryYellow, Color textBase = DefaultColors.text_gray_base, Color textBlack = DefaultColors.text_text_black, Color textDisabled = DefaultColors.text_gray_disabled, Color textWhite = DefaultColors.text_text_white, TextTheme? textTheme, BorderRadius? textFieldRadius, double? textFieldBorderWidth, BorderRadius? buttonsRadius, InputDecorationThemeData? inputDecorationTheme, ElevatedButtonThemeData? elevatedButtonTheme, OutlinedButtonThemeData? outlinedButtonTheme, SwitchThemeData? switchTheme, ChipThemeData? chipTheme, bool useMaterial3 = true}) → ThemeData
Base utility to create a standard Flutter ThemeData configured with GB UI Kit styling, button styles, input decorations, and typography.
darken(Color color, [double amount = .1]) → Color
lighten(Color color, [double amount = .1]) → Color
showAppModal<T>(BuildContext context, {Widget? title, Widget? message, List<Widget>? actions, Widget? customCloseIcon, Widget? icon, Color? backgroundColor, ShapeBorder? shape, bool barrierDismissible = false, EdgeInsetsGeometry? contentPadding, EdgeInsets? insetPadding, bool useRootNavigator = true, Axis actionsDirection = Axis.vertical, double titlesActionsSpacing = 60, double iconTitlesSpacing = 16, double textsSpacing = 16, double actionsSpacing = 16}) → Future<T?>
showCupertinoAlert(BuildContext context, {String? title, String? content, List<Widget>? actions}) → void
showSnackBarAlert(BuildContext context, {String? title, String? message, Color? backgroundColor, SnackbarAlertType? type, Duration? duration = const Duration(seconds: 3)}) → ScaffoldFeatureController<Widget, dynamic>

Typedefs

AnimatedStateListItemBuilder<T> = Widget Function(BuildContext context, int index, Animation<double> animation, T item)
IdMapper<T> = String Function(T item)
SelectTrailingBuilder = Widget Function(BuildContext context, int index, bool isSelected)
WrapWidgetBuilder = Widget Function(BuildContext context, Widget defaultWidget)