AccountCodeConfirmationTemplate class

Inheritance
Available extensions

Constructors

AccountCodeConfirmationTemplate({Key? key, void onCodeChange(String code)?, void onResendCode()?, required void onSubmit(String code), EdgeInsets padding = const EdgeInsets.only(top: 24, bottom: 16, left: 16, right: 16), bool? canSubmit, bool submitting = false, bool resendingCode = false, bool centerCodeField = false, bool hideCodeFieldLabel = false, bool hideConfirmAndDescriptionSection = false, String? codeFieldLabel, int codeLength = 6, double headerTextsSpace = 0, double headerBottomSpace = 40, String? confirmText, String? descriptionText, String? buttonText, Color? confirmTextColor, Color? descriptionTextColor, TextStyle? legendActionStyle, ButtonTemplatePosition buttonPosition = ButtonTemplatePosition.END_OF_SCREEN, ButtonTemplatePosition legendPosition = ButtonTemplatePosition.END_OF_SCREEN, List<InputFeedbackText> codeFieldFeedback = const [], bool wrapInSafeArea = true, bool forceUppercase = false, TextInputType? keyboardType, String? codeValue})
const

Properties

buttonPosition → ButtonTemplatePosition
The position where the button will be placed
final
buttonText → String?
Text shown in the button
final
canSubmit → bool?
final
centerCodeField → bool
final
codeFieldFeedback → List<InputFeedbackText>
Code field feedback
final
codeFieldLabel → String?
final
codeLength → int
final
codeValue → String?
Provide a way to change code field input value
final
confirmText → String?
H1 custom text
final
confirmTextColor → Color?
The H1 text color
final
descriptionText → String?
H3 custom text
final
descriptionTextColor → Color?
The H3 text color
final
forceUppercase → bool
Should force text to be uppercase defaults to false
final
hashCode → int
The hash code for this object.
no setterinherited
headerBottomSpace → double
Space between head and code field
final
headerTextsSpace → double
Space between confirmText and descriptionText
final
hideCodeFieldLabel → bool
final
hideConfirmAndDescriptionSection → bool
Remove the confirm text and description section
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType?
The keyboard styling for the code input field
final
legendActionStyle → TextStyle?
The style applied to the legend action
final
legendPosition → ButtonTemplatePosition
The position where the legend will be placed
final
onCodeChange → void Function(String code)?
final
onResendCode → void Function()?
final
onSubmit → void Function(String code)
final
padding → EdgeInsets
final
resendingCode → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
submitting → bool
final
wrapInSafeArea → bool
if should wrap body in safe are defaults to true
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<AccountCodeConfirmationTemplate>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
withGBInputWrapper({String? label, Widget? labelWidget, bool appendColonToLabel = true, TextStyle? labelStyle, String? errorText, bool hasError = false, List<InputFeedbackText>? feedback, WrapWidgetBuilder? innerBoxWrapper, BoxConstraints? constraints}) → Widget

Available on Widget, provided by the GBInputWrapperExtension extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited