GBText class

Inheritance
Available extensions
Annotations
  • @Deprecated('Use standard Flutter Text with Theme.of(context).textTheme instead')

Constructors

GBText(String? text, {Key? key, TextAlign? textAlign, TextStyle? style, int? maxLines})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxLines → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → TextStyle?
final
text → String?
final
textAlign → TextAlign?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
withGBInputWrapper({String? label, Widget? labelWidget, bool appendColonToLabel = true, TextStyle? labelStyle, String? errorText, bool hasError = false, List<InputFeedbackText>? feedback, WrapWidgetBuilder? innerBoxWrapper, BoxConstraints? constraints}) → Widget

Available on Widget, provided by the GBInputWrapperExtension extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

body(String text, {BuildContext? context, TextAlign? textAlign, Key? key, Color? color, TextStyle? style}) → Widget
body2(String text, {BuildContext? context, TextAlign? textAlign, Key? key, Color? color, TextStyle? style}) → Widget
button(String text, {BuildContext? context, TextAlign? textAlign, Key? key, Color? color, TextStyle? style}) → Widget
caption(String? text, {BuildContext? context, TextAlign? textAlign, Key? key, Color? color, TextStyle? style}) → Widget
h1(String text, {BuildContext? context, TextAlign? textAlign, Key? key, Color? color, TextStyle? style}) → Widget
h2(String text, {BuildContext? context, TextAlign? textAlign, Key? key, Color? color, TextStyle? style}) → Widget
h3(String text, {BuildContext? context, TextAlign? textAlign, Key? key, Color? color, TextStyle? style}) → Widget
h4(String? text, {BuildContext? context, TextAlign? textAlign, Key? key, Color? color, TextStyle? style}) → Widget
h5(String text, {BuildContext? context, TextAlign? textAlign, Key? key, Color? color, TextStyle? style}) → Widget
h6(String text, {BuildContext? context, TextAlign? textAlign, Key? key, Color? color, TextStyle? style}) → Widget
overline(String text, {BuildContext? context, TextAlign? textAlign, Key? key, Color? color, TextStyle? style}) → Widget
small(String text, {BuildContext? context, TextAlign? textAlign, Key? key, Color? color, TextStyle? style}) → Widget
subtitle(String text, {BuildContext? context, TextAlign? textAlign, Key? key, Color? color, TextStyle? style}) → Widget
subtitle2(String text, {BuildContext? context, TextAlign? textAlign, Key? key, Color? color, TextStyle? style}) → Widget