GBThemeDataExtension extension

Extension on ThemeData providing GB UI Kit theme builder and token accessors.

on

Properties

gbAccentColor Color

Available on ThemeData, provided by the GBThemeDataExtension extension

Direct token accessors for convenience when migrating from GBTheme.of(context)
no setter
gbAccentError Color

Available on ThemeData, provided by the GBThemeDataExtension extension

no setter
gbBackgroundBase Color

Available on ThemeData, provided by the GBThemeDataExtension extension

no setter
gbBackgroundContrast Color

Available on ThemeData, provided by the GBThemeDataExtension extension

no setter
gbBackgroundDisabled Color

Available on ThemeData, provided by the GBThemeDataExtension extension

no setter
gbBackgroundFocus Color

Available on ThemeData, provided by the GBThemeDataExtension extension

no setter
gbTextBlack Color

Available on ThemeData, provided by the GBThemeDataExtension extension

no setter
gbTextDisabled Color

Available on ThemeData, provided by the GBThemeDataExtension extension

no setter
gbTextWhite Color

Available on ThemeData, provided by the GBThemeDataExtension extension

no setter

Methods

copyWithGBDefaults({Color? accentColor, Color? accentError, Color? textWhite, Color? textBlack, Color? textDisabled, Color? backgroundDisabled, BorderRadiusGeometry? buttonsRadius, BorderRadius? textFieldRadius, double? textFieldBorderWidth, InputDecorationThemeData? inputDecorationTheme, ElevatedButtonThemeData? elevatedButtonTheme, OutlinedButtonThemeData? outlinedButtonTheme, SwitchThemeData? switchTheme, ChipThemeData? chipTheme}) ThemeData

Available on ThemeData, provided by the GBThemeDataExtension extension

Applies GB UI Kit button and input styling on top of this ThemeData.

Static Methods

gb({Color accentColor = DefaultColors.accent_accent_blue, Color accentError = DefaultColors.accent_error_red, Color accentErrorLight = DefaultColors.accent_error_red_light, Color backgroundBase = DefaultColors.background_base, Color backgroundContrast = DefaultColors.background_contrast, Color backgroundDisabled = DefaultColors.background_disabled, Color backgroundFocus = DefaultColors.background_focus, Color primaryColor = DefaultColors.primaryPrimaryYellow, Color textBase = DefaultColors.text_gray_base, Color textBlack = DefaultColors.text_text_black, Color textDisabled = DefaultColors.text_gray_disabled, Color textWhite = DefaultColors.text_text_white, TextTheme? textTheme, BorderRadius? textFieldRadius, double? textFieldBorderWidth, BorderRadius? buttonsRadius, InputDecorationThemeData? inputDecorationTheme, ElevatedButtonThemeData? elevatedButtonTheme, OutlinedButtonThemeData? outlinedButtonTheme, SwitchThemeData? switchTheme, ChipThemeData? chipTheme, bool useMaterial3 = true}) ThemeData

Available on ThemeData, provided by the GBThemeDataExtension extension

Factory method to create a ThemeData with GB UI Kit predefined styling.