GenericDataHandlerWidget class

A widget that helps you handling loading, errors and data through the UI with animations

Inheritance
Available extensions

Constructors

GenericDataHandlerWidget({Key? key, required bool hasError, required String errorMessage, required bool isLoading, required Widget loadingChild, required Widget child, String? errorTitle, String? buttonText, ContainedButton? customButton, TextStyle? titleStyle, TextStyle? messageStyle, void onTryAgain()?, bool buttonUppercase = true, bool buttonIsBusy = false, Clip clipBehavior = Clip.hardEdge})
const

Properties

buttonIsBusy → bool
final
buttonText → String?
final
buttonUppercase → bool
final
child → Widget
The widget that will be shown when there is none error
final
clipBehavior → Clip
final
customButton → ContainedButton?
final
errorMessage → String
final
errorTitle → String?
final
hasError → bool
final
hashCode → int
The hash code for this object.
no setterinherited
isLoading → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingChild → Widget
The diget that will be shown while loading
final
messageStyle → TextStyle?
final
onTryAgain → void Function()?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
titleStyle → TextStyle?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
withGBInputWrapper({String? label, Widget? labelWidget, bool appendColonToLabel = true, TextStyle? labelStyle, String? errorText, bool hasError = false, List<InputFeedbackText>? feedback, WrapWidgetBuilder? innerBoxWrapper, BoxConstraints? constraints}) → Widget

Available on Widget, provided by the GBInputWrapperExtension extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited