DefaultLoadingStyle class

Constructors

DefaultLoadingStyle({Color? loadingColor, Color? loadingBackgroundColor, double overlayOpacity = 0.5, Color? overlayColor, Widget? builder})
const

Properties

builder → Widget?
If you want to completely customize the way the loader is show seg a custom builder this builder will provide the default widget so you can wrap it if needed
final
hashCode → int
The hash code for this object.
no setterinherited
loadingBackgroundColor → Color?
Color for the loading background indicator
final
loadingColor → Color?
Color for the loading value indicator
final
overlayColor → Color?
Color for the overlay
final
overlayOpacity → double
Opacity for the overlay Defaults to 0.5
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited