valueMapper property
Every time the indicatorNotifier triggers this callback will be processed to get the indicator/loading state
Implementation
final bool Function()? valueMapper;
Every time the indicatorNotifier triggers this callback will be processed to get the indicator/loading state
final bool Function()? valueMapper;