SelectableRadio<T> class

Inheritance
Available extensions

Constructors

SelectableRadio({Key? key, required T value, required T groupValue, void onChanged(T)?, bool filled = false, bool disabled = false, bool enableSplashColor = false, double? size, Color? filledColor, Border? border, Color? activeColor, Color? inactiveColor, Color? disabledColor, Widget? activeChild, String? label, TextStyle? labelStyle})
const

Properties

activeChild → Widget?
final
activeColor → Color?
final
border → Border?
final
disabled → bool
final
disabledColor → Color?
final
enableSplashColor → bool
final
filled → bool
final
filledColor → Color?
final
groupValue → T
final
hashCode → int
The hash code for this object.
no setterinherited
inactiveColor → Color?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String?
final
labelStyle → TextStyle?
final
onChanged → void Function(T)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double?
final
value → T
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<SelectableRadio<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
withGBInputWrapper({String? label, Widget? labelWidget, bool appendColonToLabel = true, TextStyle? labelStyle, String? errorText, bool hasError = false, List<InputFeedbackText>? feedback, WrapWidgetBuilder? innerBoxWrapper, BoxConstraints? constraints}) → Widget

Available on Widget, provided by the GBInputWrapperExtension extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited