PickedTime class

Constructors

PickedTime({required int hour, required int minutes, required bool isAM})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
hour → int
final
isAM → bool
final
minutes → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited