TimePicker class

Inheritance
Available extensions

Constructors

TimePicker({Key? key, void onChanged(String time, bool isAvailableTime)?, void onChangedParsed(PickedTime time, bool isAvailableTime)?, int? initialHour, int? initialMinutes, bool initWithAM = true, int? availableAfterHours, int? availableAfterMinutes, List<UnavailableTime>? unavailableTimes, String? unavailableLegend, TextStyle? activeTimeStyle, TextStyle? disabledTimeStyle})
const

Properties

activeTimeStyle → TextStyle?
final
availableAfterHours → int?
Starts the picker in the current deevice hour plus the specified hours but disabling the before hours, i.e. current time is 11:00 am and availableAfterHours = 2, the picker will start at 1:00 pm
final
availableAfterMinutes → int?
Starts the picker in the current device minutes plus the specified minutes but disabling the before minute, i.e. current time is 11:40 am and availableAfterMinutes = 20, the picker will start at 12:00 am
final
disabledTimeStyle → TextStyle?
final
hashCode → int
The hash code for this object.
no setterinherited
initialHour → int?
Starts the picker in the specified hour
final
initialMinutes → int?
Starts the picker in the specified minutes
final
initWithAM → bool
If the picker should start with AM instead of PM
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged → void Function(String time, bool isAvailableTime)?
final
onChangedParsed → void Function(PickedTime time, bool isAvailableTime)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unavailableLegend → String?
final
unavailableTimes → List<UnavailableTime>?
Intervals of time that will be disabled.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<TimePicker>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
withGBInputWrapper({String? label, Widget? labelWidget, bool appendColonToLabel = true, TextStyle? labelStyle, String? errorText, bool hasError = false, List<InputFeedbackText>? feedback, WrapWidgetBuilder? innerBoxWrapper, BoxConstraints? constraints}) → Widget

Available on Widget, provided by the GBInputWrapperExtension extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited