UnavailableTime class

Constructors

UnavailableTime({required int hour, required int disableMinutesFrom, required int disableMinutesTo, required bool disableEntireHour})
const

Properties

disableEntireHour → bool
Disables completely the hour and minutes.
final
disableMinutesFrom → int
Set the initial range where the minutes will be disabled. I.e. If we want disable 9:00 to 9:10 interval then we should set disableMinutesFrom: 0 and disableMinutesTo: 10.
final
disableMinutesTo → int
Closes the range where the minutes will be disabled. I.e. If we want disable 9:00 to 9:10 then we should set disableMinutesFrom: 0 and disableMinutesTo: 10.
final
hashCode → int
The hash code for this object.
no setterinherited
hour → int
The hour where the minutes will be disabled or the hour that will be disabled along with the minutes. It should be in 24h format.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited