builder property
The builder function that is called every time the timer ticks.
Implementation
final Widget Function(BuildContext context, TimerCountDownState state)
builder;
The builder function that is called every time the timer ticks.
final Widget Function(BuildContext context, TimerCountDownState state)
builder;