timerCompleted property
bool
get
timerCompleted
Returns true if the timer has reached zero or is negative.
Implementation
bool get timerCompleted {
return timeToEnd.compareTo(Duration.zero) == 0;
}
Returns true if the timer has reached zero or is negative.
bool get timerCompleted {
return timeToEnd.compareTo(Duration.zero) == 0;
}