GBButtonGradient class
- Annotations
Constructors
-
GBButtonGradient({required List<
WidgetStateProperty< colors, AlignmentGeometry begin = Alignment.centerLeft, AlignmentGeometry end = Alignment.centerRight})Color> > -
const
Properties
- begin → AlignmentGeometry
-
final
-
colors
→ List<
WidgetStateProperty< Color> > -
final
- end → AlignmentGeometry
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
Set< WidgetState> states) → LinearGradient -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override