GBTheme class
- Inheritance
- Available extensions
- Annotations
-
- @Deprecated('Use standard Flutter Theme instead')
Constructors
- GBTheme({Key? key, GBThemeData? data, required Widget child})
Properties
- child → Widget
-
final
- data → GBThemeData
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
withGBInputWrapper(
{String? label, Widget? labelWidget, bool appendColonToLabel = true, TextStyle? labelStyle, String? errorText, bool hasError = false, List< InputFeedbackText> ? feedback, WrapWidgetBuilder? innerBoxWrapper, BoxConstraints? constraints}) → Widget -
Available on Widget, provided by the GBInputWrapperExtension extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
accentColorOf(
BuildContext context) → Color -
backgroundContrast(
BuildContext context) → Color -
backgroundDisabled(
BuildContext context) → Color -
backgroundFocus(
BuildContext context) → Color -
createTheme(
{Color accentColor = DefaultColors.accent_accent_blue, Color accentError = DefaultColors.accent_error_red, Color accentErrorLight = DefaultColors.accent_error_red_light, Color backgroundBase = DefaultColors.background_base, Color backgroundContrast = DefaultColors.background_contrast, Color backgroundDisabled = DefaultColors.background_disabled, Color backgroundFocus = DefaultColors.background_focus, Color primaryColor = DefaultColors.primaryPrimaryYellow, Color textBase = DefaultColors.text_gray_base, Color textBlack = DefaultColors.text_text_black, Color textDisabled = DefaultColors.text_gray_disabled, Color textWhite = DefaultColors.text_text_white, TextTheme? textTheme, BorderRadius? textFieldRadius, double? textFieldBorderWidth, BorderRadius? buttonsRadius, InputDecorationThemeData? inputDecorationTheme, ElevatedButtonThemeData? elevatedButtonThemeData, OutlinedButtonThemeData? outlinedButtonThemeData, SwitchThemeData? switchTheme, ChipThemeData? chipTheme, bool useMaterial3 = true}) → ThemeData - Creates a standard ThemeData preconfigured with GB UI Kit styles and button defaults.
-
errorColorOf(
BuildContext context) → Color -
errorLightColorOf(
BuildContext context) → Color -
maybeOf(
BuildContext context) → GBThemeData? -
of(
BuildContext context) → GBThemeData -
textDisabledOf(
BuildContext context) → Color