builder property
A function that will be used to build the loading indicator overlay if not provided a default one will be used that can be customized with the DefaultLoadingStyle
Implementation
final Widget Function(BuildContext context)? builder;
A function that will be used to build the loading indicator overlay if not provided a default one will be used that can be customized with the DefaultLoadingStyle
final Widget Function(BuildContext context)? builder;