indicatorNotifier property
A notifier to add an internal listener that will be used to act on loading state changes You must define a valueMapper for this
Implementation
final ValueNotifier<dynamic>? indicatorNotifier;
A notifier to add an internal listener that will be used to act on loading state changes You must define a valueMapper for this
final ValueNotifier<dynamic>? indicatorNotifier;