TimerCountDownState class
Represents the current state of a TimerCountDownBuilder.
Contains the remaining duration and helper methods for formatting.
Constructors
- TimerCountDownState({required Duration timeToEnd})
-
Creates a new TimerCountDownState with the given
timeToEnd.const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timerCompleted → bool
-
Returns
trueif the timer has reached zero or is negative.no setter - timeToEnd → Duration
-
The remaining duration until the target date is reached.
final
- timeToEndFormatted → String
-
Returns a formatted string representation of the remaining time.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override